<?php

namespace FiloBlu\OrderStatus\Plugin\Sales\Block\Adminhtml\Order;

use Magento\Sales\Block\Adminhtml\Order\View as OrderView;
use Magento\Framework\UrlInterface;
use Magento\Framework\AuthorizationInterface;
use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Store\Model\ScopeInterface;

class View {
    
    const ADYEN_CREDIT_CARD_PAYMENT_NAME = ['adyen_cc', 'adyen_oneclick'];
    const ADYEN_PAYMENT_REVIEW_PENDING_ORDER_STATUS_CONFIG_PATH = 'payment/adyen_abstract/fraud_manual_review_status';
    const ADYEN_PAYMENT_REVIEW_ACCEPTED_ORDER_STATUS_CONFIG_PATH = 'payment/adyen_abstract/fraud_manual_review_accept_status';

    /** @var \Magento\Framework\UrlInterface */
    protected $_urlBuilder;

    /** @var \Magento\Framework\AuthorizationInterface */
    protected $_authorization;
    
    protected $_config;

    public function __construct(
    UrlInterface $url, AuthorizationInterface $authorization, ScopeConfigInterface $config
    ) {
        $this->_urlBuilder = $url;
        $this->_authorization = $authorization;
        $this->_config = $config;
    }

    public function beforeSetLayout(OrderView $view) {
        $order = $view->getOrder();
        try {
            $method = $order->getPayment()->getMethod();
        } catch (\Exception $e) {
            $method = NULL;
        }
        
        if (in_array($method, self::ADYEN_CREDIT_CARD_PAYMENT_NAME) && 
                $order->getStatus() == $this->_config->getValue(self::ADYEN_PAYMENT_REVIEW_PENDING_ORDER_STATUS_CONFIG_PATH, ScopeInterface::SCOPE_STORE)) {
            
            $message = __('Are you sure you want to restore this order? Use it only when order is in expired manual review on Adyen.');
            $url = $this->_urlBuilder->getUrl('filobluorderstatusrestore/Order/Restore', ['id' => $view->getOrderId()]);

            $view->addButton(
                    'filoblu_orderstatus_restore_button', [
                        'label' => __('Unlock Exp. Manual Review'),
                        'onclick' => "confirmSetLocation('{$message}', '{$url}')"
                        //'data_attribute' => [
                        //    'url' => $url
                        //]
                    ]
            );
        
        }
    }

}
